@@ -1,8 +1,8 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 #
-# Copyright (C) 2017 Dell, Inc.
+# Copyright 2017 Dell, Inc.
 #
-# SPDX-License-Identifier: LGPL-2.1+
+# SPDX-License-Identifier: LGPL-2.1-or-later
 #
 import os
 import sys
@@ -22,7 +22,7 @@ def update_debian_control(target):
         print(f"Missing file {control_in}")
         sys.exit(1)
 
-    with open(control_in, "r") as rfd:
+    with open(control_in) as rfd:
         lines = rfd.readlines()
 
     deps, QUBES = parse_control_dependencies()
@@ -31,7 +31,7 @@ def update_debian_control(target):
     if QUBES:
         lines += "\n"
         control_qubes_in = os.path.join(target, "control.qubes.in")
-        with open(control_qubes_in, "r") as rfd:
+        with open(control_qubes_in) as rfd:
             lines += rfd.readlines()
 
     with open(control_out, "w") as wfd:
@@ -54,7 +54,7 @@ def update_debian_copyright(directory):
         print(f"Missing file {copyright_in}")
         sys.exit(1)
 
-    # Assume all files are remaining LGPL-2.1+
+    # Assume all files are remaining LGPL-2.1-or-later
     copyrights = []
     for root, dirs, files in os.walk("."):
         for file in files:
@@ -63,7 +63,7 @@ def update_debian_copyright(directory):
             if target.startswith("./po/") or file == "COPYING":
                 continue
             try:
-                with open(target, "r") as rfd:
+                with open(target) as rfd:
                     # read about the first few lines of the file only
                     lines = rfd.readlines(220)
             except UnicodeDecodeError:
@@ -71,14 +71,14 @@ def update_debian_copyright(directory):
             except FileNotFoundError:
                 continue
             for line in lines:
-                if "Copyright (C) " in line:
-                    parts = line.split("Copyright (C)")[
+                if "Copyright " in line:
+                    parts = line.split("Copyright")[
                         1
                     ].strip()  # split out the copyright header
                     partition = parts.partition(" ")[2]  # remove the year string
                     copyrights += [f"{partition}"]
     copyrights = "\n\t   ".join(sorted(set(copyrights)))
-    with open(copyright_in, "r") as rfd:
+    with open(copyright_in) as rfd:
         lines = rfd.readlines()
 
     with open(copyright_out, "w") as wfd:
@@ -86,7 +86,7 @@ def update_debian_copyright(directory):
             if line.startswith("%%%DYNAMIC%%%"):
                 wfd.write("Files: *\n")
                 wfd.write(f"Copyright: {copyrights}\n")
-                wfd.write("License: LGPL-2.1+\n")
+                wfd.write("License: LGPL-2.1-or-later\n")
                 wfd.write("\n")
             else:
                 wfd.write(line)
