@@ -1,10 +1,10 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 #
-# Copyright (C) 2017 Dell, Inc.
-# Copyright (C) 2020 Intel, Inc.
-# Copyright (C) 2021 Mario Limonciello
+# Copyright 2017 Dell, Inc.
+# Copyright 2020 Intel, Inc.
+# Copyright 2021 Mario Limonciello
 #
-# SPDX-License-Identifier: LGPL-2.1+
+# SPDX-License-Identifier: LGPL-2.1-or-later
 #
 import os
 import sys
@@ -18,19 +18,39 @@ MINIMUM_MARKDOWN = (3, 2, 0)
 
 
 def get_possible_profiles():
-    return ["fedora", "centos", "debian", "ubuntu", "arch", "void"]
+    return ["fedora", "centos", "debian", "ubuntu", "arch", "darwin", "freebsd"]
 
 
 def detect_profile():
+    if os.path.exists("/Library/Apple"):
+        return "darwin"
+
     try:
         import distro
 
         target = distro.id()
-        if not target in get_possible_profiles():
+        if target == "rhel":
+            return "centos"
+        if target not in get_possible_profiles():
             target = distro.like()
+        return target
     except ModuleNotFoundError:
-        target = ""
-    return target
+        pass
+
+    # fallback
+    try:
+        with open("/etc/os-release", "rb") as f:
+            for line in f.read().decode().split("\n"):
+                if line.startswith("ID="):
+                    target = line[3:].replace('"', "")
+                    if target == "rhel":
+                        return "centos"
+                    return target
+    except FileNotFoundError:
+        pass
+
+    # failed
+    return ""
 
 
 def pip_install_package(debug, name):
@@ -67,7 +87,7 @@ def get_minimum_meson_version():
 
     directory = os.path.join(os.path.dirname(sys.argv[0]), "..", "..")
 
-    with open(os.path.join(directory, "meson.build"), "r") as f:
+    with open(os.path.join(directory, "meson.build")) as f:
         for line in f:
             if "meson_version" in line:
                 return re.search(r"(\d+\.\d+\.\d+)", line).group(1)
@@ -125,12 +145,10 @@ def parse_dependencies(OS, variant, add_control):
                     inclusive = " ".join(inclusive).strip()
                     exclusive = " !".join(exclusive).strip()
                     if exclusive:
-                        exclusive = "!%s" % exclusive
-                    control = " [%s%s]" % (inclusive, exclusive)
+                        exclusive = f"!{exclusive}"
+                    control = f" [{inclusive}{exclusive}]"
             for package in distro.findall("package"):
-                if variant:
-                    if "variant" not in package.attrib:
-                        continue
+                if variant and "variant" in package.attrib:
                     if package.attrib["variant"] != variant:
                         continue
                 if package.text:
@@ -143,9 +161,9 @@ def parse_dependencies(OS, variant, add_control):
     return deps
 
 
-def _validate_deps(os, deps):
+def _validate_deps(profile: str, deps):
     validated = deps
-    if os == "debian" or os == "ubuntu":
+    if profile == "debian" or profile == "ubuntu":
         try:
             from apt import cache
 
@@ -163,35 +181,39 @@ def _validate_deps(os, deps):
     return validated
 
 
-def get_build_dependencies(os, variant):
-    parsed = parse_dependencies(os, variant, False)
-    return _validate_deps(os, parsed)
+def get_build_dependencies(profile: str, variant: str):
+    parsed = parse_dependencies(profile, variant, False)
+    return _validate_deps(profile, parsed)
 
 
-def _get_installer_cmd(os, yes):
-    if os == "debian" or os == "ubuntu":
+def _get_installer_cmd(profile: str, yes: bool):
+    if profile == "darwin":
+        return ["brew", "install"]
+    if profile in ["debian", "ubuntu"]:
         installer = ["apt", "install"]
-    elif os == "fedora":
+    elif profile in ["fedora", "centos"]:
         installer = ["dnf", "install"]
-    elif os == "arch":
+    elif profile == "arch":
         installer = ["pacman", "-Syu", "--noconfirm", "--needed"]
-    elif os == "void":
-        installer = ["xbps-install", "-Syu"]
+    elif profile == "freebsd":
+        installer = ["pkg", "install"]
     else:
         print("unable to detect OS profile, use --os= to specify")
-        print("\tsupported profiles: %s" % get_possible_profiles())
+        print(f"\tsupported profiles: {get_possible_profiles()}")
         sys.exit(1)
+    if os.geteuid() != 0:
+        installer.insert(0, "sudo")
     if yes:
         installer += ["-y"]
     return installer
 
 
-def install_packages(os, variant, yes, debugging, packages):
+def install_packages(profile: str, variant: str, yes: bool, debugging: bool, packages):
     import subprocess
 
     if packages == "build-dependencies":
-        packages = get_build_dependencies(os, variant)
-    installer = _get_installer_cmd(os, yes)
+        packages = get_build_dependencies(profile, variant)
+    installer = _get_installer_cmd(profile, yes)
     installer += packages
     if debugging:
         print(installer)
@@ -199,7 +221,6 @@ def install_packages(os, variant, yes, debugging, packages):
 
 
 if __name__ == "__main__":
-
     command = None
     # compat mode for old training documentation
     if "generate_dependencies.py" in sys.argv[0]:
@@ -261,4 +282,11 @@ if __name__ == "__main__":
             args.os, args.variant, args.yes, args.debug, "build-dependencies"
         )
     elif command == "install-pip":
-        install_packages(args.os, args.variant, args.yes, args.debug, ["python3-pip"])
+        if args.os == "darwin":
+            install_packages(args.os, args.variant, args.yes, args.debug, ["python"])
+        elif args.os == "freebsd":
+            install_packages(args.os, args.variant, args.yes, args.debug, ["py311-pip"])
+        else:
+            install_packages(
+                args.os, args.variant, args.yes, args.debug, ["python3-pip"]
+            )
