@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 #
 # Helper script to generate a list of translations
 # Sample call:
@@ -6,9 +6,9 @@
 # will lead to ./libfwupdplugin/tests/bios-attrs/dell-xps13-9310/strings.txt
 # which can be added to po/POTFILES.in
 #
-# Copyright (C) 2022  Mario Limonciello <superm1@gmail.com>
+# Copyright 2022 Mario Limonciello <superm1@gmail.com>
 #
-# SPDX-License-Identifier: LGPL-2.1+
+# SPDX-License-Identifier: LGPL-2.1-or-later
 
 import os
 import sys
@@ -21,7 +21,7 @@ def populate_translations(path):
             val: str = ""
             if not file.endswith("display_name"):
                 continue
-            with open(os.path.join(root, file), "r") as f:
+            with open(os.path.join(root, file)) as f:
                 val = f.read().replace('"', "").strip()
             if not val:
                 continue
