@@ -31,8 +31,14 @@ void
 fwupd_remote_set_filename_cache(FwupdRemote *self, const gchar *filename) G_GNUC_NON_NULL(1);
 void
 fwupd_remote_set_metadata_uri(FwupdRemote *self, const gchar *metadata_uri) G_GNUC_NON_NULL(1);
+guint64
+fwupd_remote_get_mtime(FwupdRemote *self) G_GNUC_NON_NULL(1);
 void
 fwupd_remote_set_mtime(FwupdRemote *self, guint64 mtime) G_GNUC_NON_NULL(1);
+gboolean
+fwupd_remote_ensure_mtime(FwupdRemote *self, GError **error) G_GNUC_NON_NULL(1);
+gboolean
+fwupd_remote_ensure_checksum_sig(FwupdRemote *self, GError **error) G_GNUC_NON_NULL(1);
 gchar **
 fwupd_remote_get_order_after(FwupdRemote *self) G_GNUC_NON_NULL(1);
 gchar **
