@@ -167,10 +167,7 @@ fu_device_locker_new_full(FuDevice *device,
 	if (!self->open_func(device, error)) {
 		g_autoptr(GError) error_local = NULL;
 		if (!self->close_func(device, &error_local)) {
-			if (!g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO)) {
-				g_debug("ignoring close error on aborted open: %s",
-					error_local->message);
-			}
+			g_debug("ignoring close error on aborted open: %s", error_local->message);
 		}
 		return NULL;
 	}
