@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2017 Richard Hughes <richard@hughsie.com>
+ * Copyright 2017 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #pragma once
@@ -22,7 +22,7 @@ typedef enum {
 	FU_DUMP_FLAGS_SHOW_ADDRESSES = 1 << 1,
 	/*< private >*/
 	FU_DUMP_FLAGS_LAST
-} FuDumpFlags;
+} G_GNUC_FLAG_ENUM FuDumpFlags;
 
 void
 fu_dump_raw(const gchar *log_domain, const gchar *title, const guint8 *data, gsize len)
