@@ -19,3 +19,5 @@ G_DECLARE_FINAL_TYPE(FuKernelSearchPathLocker,
 FuKernelSearchPathLocker *
 fu_kernel_search_path_locker_new(const gchar *path, GError **error) G_GNUC_WARN_UNUSED_RESULT
     G_GNUC_NON_NULL(1);
+const gchar *
+fu_kernel_search_path_locker_get_path(FuKernelSearchPathLocker *self) G_GNUC_NON_NULL(1);
