@@ -26,23 +26,6 @@
 #define BCM_NVRAM_INFO2_BASE	 0x200
 #define BCM_NVRAM_STAGE1_BASE	 0x28c
 
-#define BCM_NVRAM_HEADER_MAGIC	   0x00
-#define BCM_NVRAM_HEADER_PHYS_ADDR 0x04
-#define BCM_NVRAM_HEADER_SIZE_WRDS 0x08
-#define BCM_NVRAM_HEADER_OFFSET	   0x0C
-#define BCM_NVRAM_HEADER_CRC	   0x10
-#define BCM_NVRAM_HEADER_SZ	   0x14
-
-#define BCM_NVRAM_INFO_MAC_ADDR0 0x00
-#define BCM_NVRAM_INFO_VENDOR	 0x2E
-#define BCM_NVRAM_INFO_DEVICE	 0x2C
-#define BCM_NVRAM_INFO_SZ	 0x8C
-
-#define BCM_NVRAM_DIRECTORY_ADDR      0x00
-#define BCM_NVRAM_DIRECTORY_SIZE_WRDS 0x04
-#define BCM_NVRAM_DIRECTORY_OFFSET    0x08
-#define BCM_NVRAM_DIRECTORY_SZ	      0x0c
-
 #define BCM_NVRAM_VPD_SZ 0x100
 
 #define BCM_NVRAM_INFO2_SZ 0x8c
@@ -54,7 +37,7 @@ typedef struct {
 	gchar *branch;
 	gchar *version;
 	FwupdVersionFormat verfmt;
-} Bcm57xxVeritem;
+} FuBcm57xxVeritem;
 
 gboolean
 fu_bcm57xx_verify_crc(GInputStream *stream, GError **error);
@@ -63,7 +46,7 @@ fu_bcm57xx_verify_magic(GInputStream *stream, gsize offset, GError **error);
 
 /* parses stage1 version */
 void
-fu_bcm57xx_veritem_free(Bcm57xxVeritem *veritem);
-Bcm57xxVeritem *
+fu_bcm57xx_veritem_free(FuBcm57xxVeritem *veritem);
+FuBcm57xxVeritem *
 fu_bcm57xx_veritem_new(const guint8 *buf, gsize bufsz);
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(Bcm57xxVeritem, fu_bcm57xx_veritem_free)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(FuBcm57xxVeritem, fu_bcm57xx_veritem_free)
