@@ -27,8 +27,7 @@ fu_dell_dock_set_power(FuDevice *device, guint8 target, gboolean enabled, GError
 
 	g_return_val_if_fail(device != NULL, FALSE);
 
-	parent = FU_IS_DELL_DOCK_EC(device) ? device : fu_device_get_parent(device);
-
+	parent = FU_IS_DELL_DOCK_EC(device) ? device : fu_device_get_parent(device, NULL);
 	if (parent == NULL) {
 		g_set_error(error,
 			    FWUPD_ERROR,
