@@ -791,13 +791,11 @@ fu_devlink_device_close(FuDevice *device, GError **error)
 static FuKernelSearchPathLocker *
 fu_devlink_device_search_path_locker_new(FuDevlinkDevice *self, GError **error)
 {
-	g_autofree gchar *cachedir = NULL;
 	g_autofree gchar *devlink_fw_dir = NULL;
 	g_autoptr(FuKernelSearchPathLocker) locker = NULL;
 
 	/* create a directory to store firmware files for devlink plugin */
-	cachedir = fu_path_from_kind(FU_PATH_KIND_CACHEDIR_PKG);
-	devlink_fw_dir = g_build_filename(cachedir, "devlink", "firmware", NULL);
+	devlink_fw_dir = fu_path_build(FU_PATH_KIND_CACHEDIR_PKG, "devlink", "firmware", NULL);
 	if (g_mkdir_with_parents(devlink_fw_dir, 0700) == -1) {
 		g_set_error(error,
 			    FWUPD_ERROR,
