@@ -47,7 +47,7 @@ fu_elan_kbd_runtime_detach(FuDevice *device, FuProgress *progress, GError **erro
 }
 
 static void
-fu_elan_kbd_runtime_set_progress(FuDevice *self, FuProgress *progress)
+fu_elan_kbd_runtime_set_progress(FuDevice *device, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
