@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2022 Shihwei Huang <shihwei.huang@focaltech-electronics.com>
+ * Copyright 2022 Shihwei Huang <shihwei.huang@focaltech-electronics.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #pragma once
@@ -11,7 +11,5 @@
 #define FU_TYPE_FOCALFP_FIRMWARE (fu_focalfp_firmware_get_type())
 G_DECLARE_FINAL_TYPE(FuFocalfpFirmware, fu_focalfp_firmware, FU, FOCALFP_FIRMWARE, FuFirmware)
 
-FuFirmware *
-fu_focalfp_firmware_new(void);
 guint32
 fu_focalfp_firmware_get_checksum(FuFocalfpFirmware *self);
