@@ -1,5 +1,5 @@
-// Copyright (C) 2023 Goodix.inc <xulinkun@goodix.com>
-// SPDX-License-Identifier: LGPL-2.1+
+// Copyright 2023 Goodix.inc <xulinkun@goodix.com>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 enum FuGoodixtpIcType {
     None,
@@ -11,7 +11,8 @@ enum FuGoodixtpIcType {
     Yellowstone,
 }
 
-#[derive(ParseBytes)]
+#[derive(ParseStream)]
+#[repr(C, packed)]
 struct FuStructGoodixBrlbHdr {
     firmware_size: u32le,
     checksum: u32le,
@@ -21,7 +22,8 @@ struct FuStructGoodixBrlbHdr {
     _unknown: [u8; 12],
 }
 
-#[derive(ParseBytes)]
+#[derive(ParseStream)]
+#[repr(C, packed)]
 struct FuStructGoodixBrlbImg {
     kind: u8,
     size: u32le,
@@ -29,7 +31,8 @@ struct FuStructGoodixBrlbImg {
     _unknown: [u8; 1],
 }
 
-#[derive(ParseBytes)]
+#[derive(ParseStream)]
+#[repr(C, packed)]
 struct FuStructGoodixGtx8Hdr {
     firmware_size: u32be,
     checksum: u16be,
@@ -39,7 +42,8 @@ struct FuStructGoodixGtx8Hdr {
     _unknown: [u8; 4],
 }
 
-#[derive(ParseBytes)]
+#[derive(ParseStream)]
+#[repr(C, packed)]
 struct FuStructGoodixGtx8Img {
     kind: u8,
     size: u32be,
