@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2021 Mario Limonciello <mario.limonciello@amd.com>
+ * Copyright 2021 Mario Limonciello <mario.limonciello@amd.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -38,7 +38,9 @@ static void
 fu_lenovo_thinklmi_plugin_cpu_registered(FuContext *ctx, FuDevice *device)
 {
 	/* Ryzen 6000 doesn't support S3 even if the BIOS offers it */
-	if (fu_device_has_instance_id(device, "CPUID\\PRO_0&FAM_19&MOD_44")) {
+	if (fu_device_has_instance_id(device,
+				      "CPUID\\PRO_0&FAM_19&MOD_44",
+				      FU_DEVICE_INSTANCE_FLAG_VISIBLE)) {
 		FwupdBiosSetting *attr = fu_context_get_bios_setting(ctx, BIOS_SETTING_SLEEP_MODE);
 
 		if (attr != NULL) {
