@@ -119,12 +119,10 @@ fu_linux_swap_new(const gchar *buf, gsize bufsz, GError **error)
 				if (!fu_linux_swap_verify_partition(self, fn, error))
 					return NULL;
 			} else if (g_strcmp0(ty, "file") == 0) {
-				g_autofree gchar *base = NULL;
 				g_autofree gchar *path = NULL;
 
 				/* get the path to the file */
-				base = fu_path_from_kind(FU_PATH_KIND_HOSTFS_ROOT);
-				path = g_build_filename(base, fn, NULL);
+				path = fu_path_build(FU_PATH_KIND_HOSTFS_ROOT, fn, NULL);
 
 				self->enabled_cnt++;
 				if (!fu_linux_swap_verify_file(self, path, error))
