@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2016 Richard Hughes <richard@hughsie.com>
+ * Copyright 2016 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -17,8 +17,8 @@ fu_logitech_hidpp_buffer_read_uint8(const gchar *str)
 {
 	guint64 tmp;
 	gchar buf[3] = {0x0, 0x0, 0x0};
-	memcpy(buf, str, 2);
-	tmp = g_ascii_strtoull(buf, NULL, 16);
+	memcpy(buf, str, 2);		       /* nocheck:blocked */
+	tmp = g_ascii_strtoull(buf, NULL, 16); /* nocheck:blocked */
 	return tmp;
 }
 
@@ -27,8 +27,8 @@ fu_logitech_hidpp_buffer_read_uint16(const gchar *str)
 {
 	guint64 tmp;
 	gchar buf[5] = {0x0, 0x0, 0x0, 0x0, 0x0};
-	memcpy(buf, str, 4);
-	tmp = g_ascii_strtoull(buf, NULL, 16);
+	memcpy(buf, str, 4);		       /* nocheck:blocked */
+	tmp = g_ascii_strtoull(buf, NULL, 16); /* nocheck:blocked */
 	return tmp;
 }
 
