@@ -97,7 +97,7 @@ fu_mm_fastboot_device_add_json(FuDevice *device, JsonBuilder *builder, FwupdCode
 }
 
 static void
-fu_mm_fastboot_device_set_progress(FuDevice *self, FuProgress *progress)
+fu_mm_fastboot_device_set_progress(FuDevice *device, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
