@@ -13,3 +13,5 @@ G_DECLARE_FINAL_TYPE(FuNvmeDevice, fu_nvme_device, FU, NVME_DEVICE, FuPciDevice)
 
 FuNvmeDevice *
 fu_nvme_device_new_from_blob(FuContext *ctx, const guint8 *buf, gsize sz, GError **error);
+gboolean
+fu_nvme_device_set_serial(FuNvmeDevice *self, const gchar *serial, GError **error);
