@@ -100,6 +100,15 @@ fu_qc_firehose_usb_device_write(FuQcFirehoseUsbDevice *self,
 	g_autoptr(GPtrArray) chunks = NULL;
 	g_autoptr(GByteArray) bufmut = g_byte_array_sized_new(sz);
 
+	/* sanity check */
+	if (self->maxpktsize_out == 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "no max packet size defined");
+		return FALSE;
+	}
+
 	/* copy const data to mutable GByteArray */
 	g_byte_array_append(bufmut, buf, sz);
 	chunks = fu_chunk_array_mutable_new(bufmut->data, bufmut->len, 0, 0, self->maxpktsize_out);
@@ -264,6 +273,8 @@ fu_qc_firehose_usb_device_impl_write_firmware(FuDevice *device,
 static void
 fu_qc_firehose_usb_device_replace(FuDevice *device, FuDevice *donor)
 {
+	if (!FU_IS_QC_FIREHOSE_USB_DEVICE(donor))
+		return;
 	if (fu_device_has_private_flag(donor, FU_QC_FIREHOSE_USB_DEVICE_NO_ZLP))
 		fu_device_add_private_flag(device, FU_QC_FIREHOSE_USB_DEVICE_NO_ZLP);
 }
