@@ -1,5 +1,5 @@
-// Copyright (C) 2023 Richard Hughes <richard@hughsie.com>
-// SPDX-License-Identifier: LGPL-2.1+
+// Copyright 2023 Richard Hughes <richard@hughsie.com>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #[derive(ToString)]
 enum FuSynapticsCxaudioDeviceKind {
@@ -34,6 +34,7 @@ enum FuSynapticsCxaudioFileKind {
 }
 
 #[derive(Parse)]
+#[repr(C, packed)]
 struct FuStructSynapticsCxaudioCustomInfo {
     patch_version_string_address: u16le,
     cpx_patch_version: [u8; 3],
@@ -49,17 +50,23 @@ struct FuStructSynapticsCxaudioCustomInfo {
     product_string_address: u16le,
     serial_number_string_address: u16le,
 }
-#[derive(Parse)]
+
+#[derive(Parse, Default)]
+#[repr(C, packed)]
 struct FuStructSynapticsCxaudioStringHeader {
     length: u8,
     type: u8 == 0x03,
 }
-#[derive(Parse)]
+
+#[derive(Parse, Default)]
+#[repr(C, packed)]
 struct FuStructSynapticsCxaudioValiditySignature {
     magic_byte: u8 = 0x4C,    // 'L'
     eeprom_size_code: u8,
 }
+
 #[derive(Parse, Setters)]
+#[repr(C, packed)]
 struct FuStructSynapticsCxaudioPatchInfo {
     patch_signature: u8,
     patch_address: u16le,
