@@ -88,8 +88,8 @@ static gboolean
 fu_uefi_capsule_backend_linux_check_efivarfs(FuUefiCapsuleBackendLinux *self, GError **error)
 {
 	gboolean is_readonly;
-	g_autofree gchar *sysfsfwdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
-	g_autofree gchar *sysfsefivardir = g_build_filename(sysfsfwdir, "efi", "efivars", NULL);
+	g_autofree gchar *sysfsefivardir =
+	    fu_path_build(FU_PATH_KIND_SYSFSDIR_FW, "efi", "efivars", NULL);
 	g_autoptr(GUnixMountEntry) mount = NULL;
 
 	/* in the self tests */
@@ -139,7 +139,6 @@ fu_uefi_capsule_backend_linux_coldplug(FuBackend *backend, FuProgress *progress,
 	const gchar *fn;
 	g_autofree gchar *esrt_entries = NULL;
 	g_autofree gchar *esrt_path = NULL;
-	g_autofree gchar *sysfsfwdir = NULL;
 	g_autoptr(GDir) dir = NULL;
 
 	/* make sure that efivarfs is suitable */
@@ -147,8 +146,7 @@ fu_uefi_capsule_backend_linux_coldplug(FuBackend *backend, FuProgress *progress,
 		return FALSE;
 
 	/* get the directory of ESRT entries */
-	sysfsfwdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
-	esrt_path = g_build_filename(sysfsfwdir, "efi", "esrt", NULL);
+	esrt_path = fu_path_build(FU_PATH_KIND_SYSFSDIR_FW, "efi", "esrt", NULL);
 	esrt_entries = g_build_filename(esrt_path, "entries", NULL);
 	dir = g_dir_open(esrt_entries, 0, error);
 	if (dir == NULL)
@@ -227,8 +225,7 @@ fu_uefi_capsule_backend_linux_setup(FuBackend *backend,
 	/* check SMBIOS for 'UEFI Specification is supported' */
 	if (!fu_uefi_capsule_backend_linux_check_smbios_enabled(fu_backend_get_context(backend),
 								&error_local)) {
-		g_autofree gchar *fw = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
-		g_autofree gchar *fn = g_build_filename(fw, "efi", NULL);
+		g_autofree gchar *fn = fu_path_build(FU_PATH_KIND_SYSFSDIR_FW, "efi", NULL);
 		if (g_file_test(fn, G_FILE_TEST_EXISTS)) {
 			g_warning("SMBIOS BIOS Characteristics Extension Byte 2 is invalid -- "
 				  "UEFI Specification is unsupported, but %s exists: %s",
