@@ -210,28 +210,6 @@ fu_uefi_capsule_plugin_clear_results(FuPlugin *plugin, FuDevice *device, GError
 	return fu_uefi_capsule_device_clear_status(device_uefi, error);
 }
 
-static gchar *
-fu_uefi_capsule_plugin_efivars_attrs_to_string(guint32 attrs)
-{
-	const gchar *data[7] = {0};
-	guint idx = 0;
-	if (attrs & FU_EFIVARS_ATTR_NON_VOLATILE)
-		data[idx++] = "non-volatile";
-	if (attrs & FU_EFIVARS_ATTR_BOOTSERVICE_ACCESS)
-		data[idx++] = "bootservice-access";
-	if (attrs & FU_EFIVARS_ATTR_RUNTIME_ACCESS)
-		data[idx++] = "runtime-access";
-	if (attrs & FU_EFIVARS_ATTR_HARDWARE_ERROR_RECORD)
-		data[idx++] = "hardware-error-record";
-	if (attrs & FU_EFIVARS_ATTR_AUTHENTICATED_WRITE_ACCESS)
-		data[idx++] = "authenticated-write-access";
-	if (attrs & FU_EFIVARS_ATTR_TIME_BASED_AUTHENTICATED_WRITE_ACCESS)
-		data[idx++] = "time-based-authenticated-write-access";
-	if (attrs & FU_EFIVARS_ATTR_APPEND_WRITE)
-		data[idx++] = "append-write";
-	return g_strjoinv(",", (gchar **)data);
-}
-
 static void
 fu_uefi_capsule_plugin_add_security_attrs_secureboot(FuPlugin *plugin, FuSecurityAttrs *attrs)
 {
@@ -300,10 +278,10 @@ fu_uefi_capsule_plugin_add_security_attrs_bootservices(FuPlugin *plugin, FuSecur
 					  error_local->message);
 				continue;
 			}
-			if ((data_attr & FU_EFIVARS_ATTR_BOOTSERVICE_ACCESS) > 0 &&
-			    (data_attr & FU_EFIVARS_ATTR_RUNTIME_ACCESS) == 0) {
+			if ((data_attr & FU_EFI_VARIABLE_ATTR_BOOTSERVICE_ACCESS) > 0 &&
+			    (data_attr & FU_EFI_VARIABLE_ATTR_RUNTIME_ACCESS) == 0) {
 				g_autofree gchar *flags =
-				    fu_uefi_capsule_plugin_efivars_attrs_to_string(data_attr);
+				    fu_efi_variable_attrs_to_string(data_attr);
 				g_debug("%s-%s attr of size 0x%x had flags %s",
 					name,
 					guids[j],
@@ -338,15 +316,13 @@ static GBytes *
 fu_uefi_capsule_plugin_get_splash_data(guint width, guint height, GError **error)
 {
 	const gchar *const *langs = g_get_language_names();
-	g_autofree gchar *datadir_pkg = NULL;
 	g_autofree gchar *filename_archive = NULL;
 	g_autofree gchar *langs_str = NULL;
 	g_autoptr(FuArchive) archive = NULL;
 	g_autoptr(GInputStream) stream_archive = NULL;
 
 	/* load archive */
-	datadir_pkg = fu_path_from_kind(FU_PATH_KIND_DATADIR_PKG);
-	filename_archive = g_build_filename(datadir_pkg, "uefi-capsule-ux.tar.xz", NULL);
+	filename_archive = fu_path_build(FU_PATH_KIND_DATADIR_PKG, "uefi-capsule-ux.tar.xz", NULL);
 	stream_archive = fu_input_stream_from_path(filename_archive, error);
 	if (stream_archive == NULL)
 		return NULL;
@@ -376,7 +352,7 @@ fu_uefi_capsule_plugin_get_splash_data(guint width, guint height, GError **error
 		    FWUPD_ERROR_NOT_SUPPORTED,
 		    "failed to get splash file for %s in %s",
 		    langs_str,
-		    datadir_pkg);
+		    filename_archive);
 	return NULL;
 }
 
@@ -424,7 +400,7 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 		return FALSE;
 
 	fu_struct_efi_capsule_header_set_flags(st_cap,
-					       EFI_CAPSULE_HEADER_FLAGS_PERSIST_ACROSS_RESET);
+					       FU_EFI_CAPSULE_HEADER_FLAG_PERSIST_ACROSS_RESET);
 	if (!fwupd_guid_from_string(FU_EFIVARS_GUID_UX_CAPSULE,
 				    &guid,
 				    FWUPD_GUID_FLAG_MIXED_ENDIAN,
@@ -824,13 +800,11 @@ static FuFirmware *
 fu_uefi_capsule_plugin_parse_acpi_uefi(FuUefiCapsulePlugin *self, GError **error)
 {
 	g_autofree gchar *fn = NULL;
-	g_autofree gchar *path = NULL;
 	g_autoptr(FuFirmware) firmware = fu_acpi_uefi_new();
 	g_autoptr(GFile) file = NULL;
 
 	/* if we have a table, parse it and validate it */
-	path = fu_path_from_kind(FU_PATH_KIND_ACPI_TABLES);
-	fn = g_build_filename(path, "UEFI", NULL);
+	fn = fu_path_build(FU_PATH_KIND_ACPI_TABLES, "UEFI", NULL);
 	file = g_file_new_for_path(fn);
 	if (!fu_firmware_parse_file(firmware, file, FU_FIRMWARE_PARSE_FLAG_NONE, error))
 		return NULL;
