@@ -22,7 +22,6 @@ fu_uefi_grub_device_mkconfig(FuUefiCapsuleDevice *self,
 			     const gchar *target_app,
 			     GError **error)
 {
-	g_autofree gchar *bootdir = fu_path_from_kind(FU_PATH_KIND_HOSTFS_BOOT);
 	g_autofree gchar *fn_grub_cfg = NULL;
 	const gchar *argv_mkconfig[] = {"", "-o", "grub.cfg", NULL};
 	const gchar *argv_reboot[] = {"", "fwupd", NULL};
@@ -30,19 +29,18 @@ fu_uefi_grub_device_mkconfig(FuUefiCapsuleDevice *self,
 	g_autofree gchar *grub_mkconfig = NULL;
 	g_autofree gchar *grub_reboot = NULL;
 	g_autofree gchar *grub_target = NULL;
-	g_autofree gchar *localstatedir = fu_path_from_kind(FU_PATH_KIND_LOCALSTATEDIR_PKG);
 	g_autofree gchar *output = NULL;
 	g_autoptr(GString) str = g_string_new(NULL);
 
 	/* find grub.conf */
-	fn_grub_cfg = g_build_filename(bootdir, "grub", "grub.cfg", NULL);
+	fn_grub_cfg = fu_path_build(FU_PATH_KIND_HOSTFS_BOOT, "grub", "grub.cfg", NULL);
 	if (!fu_device_query_file_exists(FU_DEVICE(self), fn_grub_cfg, &exists_mkconfig, error))
 		return FALSE;
 
 	/* try harder */
 	if (!exists_mkconfig) {
 		g_free(fn_grub_cfg);
-		fn_grub_cfg = g_build_filename(bootdir, "grub2", "grub.cfg", NULL);
+		fn_grub_cfg = fu_path_build(FU_PATH_KIND_HOSTFS_BOOT, "grub2", "grub.cfg", NULL);
 	}
 	if (!fu_device_query_file_exists(FU_DEVICE(self), fn_grub_cfg, &exists_mkconfig, error))
 		return FALSE;
@@ -82,7 +80,7 @@ fu_uefi_grub_device_mkconfig(FuUefiCapsuleDevice *self,
 	g_string_append_printf(str, "EFI_PATH=%s\n", target_app);
 	g_string_replace(str, esp_path, "", 0);
 	g_string_append_printf(str, "ESP=%s\n", esp_path);
-	grub_target = g_build_filename(localstatedir, "uefi_capsule.conf", NULL);
+	grub_target = fu_path_build(FU_PATH_KIND_LOCALSTATEDIR_PKG, "uefi_capsule.conf", NULL);
 	if (!g_file_set_contents(grub_target, str->str, -1, error))
 		return FALSE;
 
