@@ -67,10 +67,10 @@ fu_uefi_dbx_device_write_firmware(FuDevice *device,
 		FU_EFIVARS_GUID_SECURITY_DATABASE,
 		"dbx",
 		fw,
-		FU_EFIVARS_ATTR_APPEND_WRITE |
-		    FU_EFIVARS_ATTR_TIME_BASED_AUTHENTICATED_WRITE_ACCESS |
-		    FU_EFIVARS_ATTR_RUNTIME_ACCESS | FU_EFIVARS_ATTR_BOOTSERVICE_ACCESS |
-		    FU_EFIVARS_ATTR_NON_VOLATILE,
+		FU_EFI_VARIABLE_ATTR_APPEND_WRITE |
+		    FU_EFI_VARIABLE_ATTR_TIME_BASED_AUTHENTICATED_WRITE_ACCESS |
+		    FU_EFI_VARIABLE_ATTR_RUNTIME_ACCESS | FU_EFI_VARIABLE_ATTR_BOOTSERVICE_ACCESS |
+		    FU_EFI_VARIABLE_ATTR_NON_VOLATILE,
 		error)) {
 		return FALSE;
 	}
