@@ -21,12 +21,10 @@ G_DEFINE_TYPE(FuUefiEsrtPlugin, fu_uefi_esrt_plugin, FU_TYPE_PLUGIN)
 static gboolean
 fu_uefi_esrt_plugin_check_esrt(void)
 {
-	g_autofree gchar *sysfsfwdir = NULL;
 	g_autofree gchar *esrtdir = NULL;
 
 	/* already exists */
-	sysfsfwdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
-	esrtdir = g_build_filename(sysfsfwdir, "efi", "esrt", NULL);
+	esrtdir = fu_path_build(FU_PATH_KIND_SYSFSDIR_FW, "efi", "esrt", NULL);
 
 	return g_file_test(esrtdir, G_FILE_TEST_EXISTS);
 }
