@@ -8,6 +8,8 @@
 
 #include <fwupdplugin.h>
 
+#include "fu-usi-dock-struct.h"
+
 #define FU_TYPE_USI_DOCK_MCU_DEVICE (fu_usi_dock_mcu_device_get_type())
 G_DECLARE_FINAL_TYPE(FuUsiDockMcuDevice,
 		     fu_usi_dock_mcu_device,
@@ -21,3 +23,7 @@ fu_usi_dock_mcu_device_write_firmware_with_idx(FuUsiDockMcuDevice *self,
 					       FuProgress *progress,
 					       FwupdInstallFlags flags,
 					       GError **error);
+
+FuDevice *
+fu_usi_dock_mcu_device_find_child(FuUsiDockMcuDevice *self, FuUsiDockFirmwareIdx chip_idx)
+    G_GNUC_NON_NULL(1);
