@@ -138,7 +138,7 @@ fu_vbe_simple_device_open(FuDevice *device, GError **error)
 			    FWUPD_ERROR_NOT_SUPPORTED,
 			    "cannot open %s [%s]",
 			    self->devname,
-			    g_strerror(errno));
+			    fwupd_strerror(errno));
 #else
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -216,7 +216,7 @@ static FuFirmware *
 fu_vbe_simple_device_prepare_firmware(FuDevice *device,
 				      GInputStream *stream,
 				      FuProgress *progress,
-				      FwupdInstallFlags flags,
+				      FuFirmwareParseFlags flags,
 				      GError **error)
 {
 	FuVbeSimpleDevice *self = FU_VBE_SIMPLE_DEVICE(device);
@@ -248,7 +248,8 @@ fu_vbe_simple_device_prepare_firmware(FuDevice *device,
 		    fu_fdt_firmware_get_image_by_path(FU_FDT_FIRMWARE(firmware), path, error);
 		if (img_firmware == NULL)
 			return NULL;
-		fu_firmware_add_image(firmware_container, FU_FIRMWARE(img_firmware));
+		if (!fu_firmware_add_image(firmware_container, FU_FIRMWARE(img_firmware), error))
+			return NULL;
 	}
 
 	/* success: return the container */
@@ -301,7 +302,7 @@ fu_vbe_simple_device_write_firmware_img(FuVbeSimpleDevice *self,
 
 	/* seek to correct address */
 	seek_to = self->area_start + store_offset + self->skip_offset;
-	g_debug("writing image '%s' bufsz 0x%x (skipping 0x%x) to store_offset 0x%x, seek 0x%x\n",
+	g_debug("writing image '%s' bufsz 0x%x (skipping 0x%x) to store_offset 0x%x, seek 0x%x",
 		fu_firmware_get_id(FU_FIRMWARE(img)),
 		(guint)bufsz,
 		(guint)self->skip_offset,
@@ -316,7 +317,7 @@ fu_vbe_simple_device_write_firmware_img(FuVbeSimpleDevice *self,
 			    "cannot seek file '%s' to 0x%x [%s]",
 			    self->devname,
 			    (guint)seek_to,
-			    g_strerror(errno));
+			    fwupd_strerror(errno));
 #else
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -337,7 +338,7 @@ fu_vbe_simple_device_write_firmware_img(FuVbeSimpleDevice *self,
 			    FWUPD_ERROR_WRITE,
 			    "cannot write file '%s' [%s]",
 			    self->devname,
-			    g_strerror(errno));
+			    fwupd_strerror(errno));
 #else
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -403,7 +404,7 @@ fu_vbe_simple_device_upload(FuDevice *device, FuProgress *progress, GError **err
 			    "cannot seek file %s to 0x%x [%s]",
 			    self->devname,
 			    (guint)self->area_start,
-			    g_strerror(errno));
+			    fwupd_strerror(errno));
 #else
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -441,7 +442,7 @@ fu_vbe_simple_device_upload(FuDevice *device, FuProgress *progress, GError **err
 }
 
 static void
-fu_vbe_simple_device_set_progress(FuDevice *self, FuProgress *progress)
+fu_vbe_simple_device_set_progress(FuDevice *device, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
