@@ -32,7 +32,7 @@ fu_wac_plugin_write_firmware(FuPlugin *plugin,
 			     FwupdInstallFlags flags,
 			     GError **error)
 {
-	FuDevice *parent = fu_device_get_parent(device);
+	FuDevice *parent = fu_device_get_parent(device, NULL);
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	locker = fu_device_locker_new(parent != NULL ? parent : device, error);
 	if (locker == NULL)
@@ -70,7 +70,11 @@ fu_wac_plugin_composite_cleanup(FuPlugin *self, GPtrArray *devices, GError **err
 			break;
 		}
 		if (FU_IS_WAC_MODULE(device_tmp)) {
-			g_set_object(&main_device, FU_WAC_DEVICE(fu_device_get_proxy(device_tmp)));
+			FuWacDevice *proxy;
+			proxy = FU_WAC_DEVICE(fu_device_get_proxy(device_tmp, error));
+			if (proxy == NULL)
+				return FALSE;
+			g_set_object(&main_device, proxy);
 			break;
 		}
 	}
